@@ -66,6 +66,7 @@ def scp(hosts, files, users=None):
             errors += transfer_file(host, file, users)
     return errors
 
+
 def _download_urls(urls):
     """Download packages from URLs, replace URLs with filenames
 
@@ -498,8 +499,7 @@ def deploy(hubs, masterfiles):
         masterfiles = os.path.abspath(os.path.expanduser(masterfiles))
         log.debug(f"Deploy path expanded to: {masterfiles}")
 
-    if masterfiles.endswith("/"):
-        masterfiles = masterfiles[0:-1]
+    masterfiles = masterfiles.rstrip("/")
 
     if os.path.isfile(masterfiles):
         return deploy_tarball(hubs, masterfiles)
